#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */

#include "peri.h"
#include "usbdrv.h"

#define RQ_SET_LED         0
#define RQ_SET_LED_VALUE   1
#define RQ_GET_SWITCH_LEFT 2
#define RQ_GET_LIGHT       3
#define RQ_GET_SWITCH_RIGHT 4



/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */
usbMsgLen_t usbFunctionSetup(uint8_t data[8])
{
    usbRequest_t *rq = (void *)data;

    static uint8_t switch_state;  

 	 if (rq->bRequest == RQ_GET_SWITCH_LEFT)
    {
	switch_state = IS_SWITCH_PRESSED_LEFT();
	usbMsgPtr = &switch_state;
        return 1;
    }

	else if (rq->bRequest == RQ_GET_SWITCH_RIGHT)
    {
	switch_state = IS_SWITCH_PRESSED_RIGHT();
	usbMsgPtr = &switch_state;
        return 1;
    }


    return 0;
}

/* ------------------------------------------------------------------------- */
int main(void)
{
    init_peripheral();

    usbInit();

    /* enforce re-enumeration, do this while interrupts are disabled! */
    usbDeviceDisconnect();
    _delay_ms(300);
    usbDeviceConnect();

    /* enable global interrupts */
    sei();

    /* main event loop */
    for(;;)
    {
        usbPoll();
    }

    return 0;
}

/* ------------------------------------------------------------------------- */
